templatetags
==================================================
**Module**: :mod:`espressodb.notifications.templatetags`


.. automodule:: espressodb.notifications.templatetags
    :members:
    :special-members:

.. autosummary::
    espressodb.notifications.templatetags.notifications_extras

.. toctree::
    :hidden:
    :glob:

    *
